"use strict";
// ==UserScript==
// @name        data extraction linkedin
// @namespace   Violentmonkey Scripts
// @match       https://www.linkedin.com/*
// @grant       GM_getValue
// @grant       GM_setValue
// @grant       GM_getValues
// @grant       GM_setValues
// @grant       GM_listValues
// @grant       GM_deleteValue
// @grant       GM_deleteValues
// @grant       GM_addStyle
// @grant       GM_addElement
// @version     0.1
// @author      Siarhei Siniak
// @license Unlicense
// @description 10/08/2024, 8:44:59 PM
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// @run-at      document-body
// @inject-into content
// @require https://cdn.jsdelivr.net/npm/@violentmonkey/dom@1
// @noframes
// ==/UserScript==
/*

Use this extension to disalbe CSP for linkedin

https://addons.mozilla.org/en-US/firefox/addon/header-editor/
https://github.com/FirefoxBar/HeaderEditor
https://github.com/violentmonkey/violentmonkey/issues/1335
https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy/script-src


{
  "request": [],
  "sendHeader": [],
  "receiveHeader": [
    {
      "enable": true,
      "name": "disable CSP for linkedin",
      "ruleType": "modifyReceiveHeader",
      "matchType": "domain",
      "pattern": "www.linkedin.com",
      "exclude": "",
      "group": "Ungrouped",
      "isFunction": false,
      "action": {
        "name": "content-security-policy",
        "value": ""
      }
    }
  ],
  "receiveBody": []
}
*/
const jquery_1 = __importDefault(require("jquery"));
class Linkedin {
    constructor() {
        this.data = new Map();
        this.ui = {
            root: null,
            entries: null,
            search: null,
            state: null,
        };
        this.state = {
            search: '',
        };
    }
    clean_page() {
        if (location.href.search('empty_body=true') != -1) {
            (0, jquery_1.default)('head').empty();
            (0, jquery_1.default)('body').empty();
            (0, jquery_1.default)('body').addClass('no-border');
        }
    }
    data_load() {
        return __awaiter(this, void 0, void 0, function* () {
            let self = this;
            const keys = yield GM_listValues();
            let loaded = 0;
            for (let o of keys) {
                if (!o.startsWith('data-')) {
                    return;
                }
                self.data.set(o.slice(5), yield GM_getValue(o));
                loaded += 1;
            }
            console.log({ action: 'loaded', total: loaded });
        });
    }
    string_reduce(text) {
        return text.replaceAll(/\s+/gi, ' ').trim();
    }
    parse_header() {
        let self = this;
        return [
            (0, jquery_1.default)('.scaffold-finite-scroll__content > div > .relative .update-components-header').map((i, o) => ({
                header: o.innerText
            })),
            (0, jquery_1.default)('.scaffold-finite-scroll__content > div > .relative .update-components-actor').map((i, o) => {
                let header = (0, jquery_1.default)(o);
                let teaser = (0, jquery_1.default)(o).parents('.relative')
                    .parent().find('.feed-shared-update-v2__description-wrapper');
                return {
                    header: self.string_reduce(header.text()),
                    teaser: self.string_reduce(teaser.text()),
                };
            })
        ];
    }
    data_add(entry) {
        return __awaiter(this, void 0, void 0, function* () {
            let self = this;
            if (self.data.has(entry.header)) {
                return false;
            }
            self.data.set(entry.header, {
                entry: entry,
                ts: (new Date()).valueOf(),
            });
            yield GM_setValue('data-' + entry.header, self.data.get(entry.header));
            console.log('saved ' + entry.header);
            console.log(self.data.get(entry.header));
            return true;
        });
    }
    document_on_changed() {
        return __awaiter(this, void 0, void 0, function* () {
            let self = this;
            let state_changed = false;
            if (JSON.stringify(self.state_get()) != JSON.stringify(self.state)) {
                state_changed = true;
                self.old_state = self.state;
                self.state = self.state_get();
            }
            let current_data = self.parse_header();
            let changed = false;
            for (let o of current_data[0]) {
                let current_changed = yield self.data_add(o);
                if (current_changed) {
                    changed = current_changed;
                }
            }
            for (let o of current_data[1]) {
                let current_changed = yield self.data_add(o);
                if (current_changed) {
                    changed = current_changed;
                }
            }
            if (changed || (state_changed ||
                self.ui.entries === null && self.data.size > 0)) {
                self.display();
            }
        });
    }
    listener_add() {
        let self = this;
        return VM.observe(document.body, () => {
            self.document_on_changed();
        });
    }
    display_init() {
        let self = this;
        self.ui.root = (0, jquery_1.default)(`<div class=online-fxreader-linkedin>`);
        (0, jquery_1.default)('head').append((0, jquery_1.default)('<style>').html(`
div.online-fxreader-linkedin {
  height: 3em;
  overflow: scroll;
  z-index: 9999;
  position: fixed;
  top: 5em;
  background: yellow;
  margin-left: 1em;
  word-wrap: anywhere;
  white-space: break-spaces;
  margin-right: 1em;
  width: calc(100% - 2em);
}

.d-none {
  display: none !important;
}

.online-fxreader-linkedin .search,
.online-fxreader-linkedin .search input
{
  height: 2em;
  line-height: 2em;
  box-sizing: border-box;
}

.no-border {
  padding: unset;
  margin: unset;
}

.online-fxreader-linkedin:hover {
  height: 10em;
}
    `));
        GM_addElement('script', {
            "textContent": `
class Linkedin {
  constructor() {
    let self = this;

    this.ui = {
      root: () => {
        return document.getElementsByClassName('online-fxreader-linkedin')[0];
      },
    };

    self.ui.search = () => {
      let search = self.ui.root().getElementsByClassName('search')[0];
      let search_input = search.getElementsByTagName('input')[0];
      return search_input;
    };
    self.ui.state = () => {
      let state = self.ui.root().getElementsByClassName('state')[0];
      return state;
    };
  }

  blah(class_name) {
    console.log('blah');
    Array.from(
      document.getElementsByClassName(class_name)
    ).forEach((o) => o.remove());
  }

  state_update(partial) {
    let self = this;

    let ui_state = self.ui.state();

    let old_state = JSON.parse(ui_state.innerText);
    ui_state.innerText = JSON.stringify(
      {
        ...old_state,
        ...partial
      }
    );
  }

  search_on_change() {
    let self = this;
    let search = self.ui.search();

    self.state_update(
      {
        search: search.value
      }
    );
  }
};
const online_fxreader_linkedin = new Linkedin();

        console.log('started');
      `
        });
        (0, jquery_1.default)(document.body).append(self.ui.root);
    }
    state_get() {
        let self = this;
        if (self.ui.state && self.ui.state.text() !== '') {
            return JSON.parse(self.ui.state.text());
        }
        else {
            return {};
        }
    }
    state_set(partial) {
        let self = this;
        self.ui.state.text(Object.assign(Object.assign({}, state_get()), partial));
    }
    display() {
        var _a;
        let self = this;
        let sorted_entries = Array.from(self.data.entries()).sort((a, b) => a[1].ts - b[1].ts);
        // self.ui.root.empty();
        if (self.ui.search === null) {
            let search = (0, jquery_1.default)('<div>').addClass('search').append((0, jquery_1.default)('<input>').val(self.state.search)).attr('onkeyup', `online_fxreader_linkedin.search_on_change()`);
            search.append((0, jquery_1.default)('<div>').addClass('total'));
            self.ui.root.append(search);
            self.ui.search = search;
        }
        if (self.ui.state === null) {
            self.ui.state = (0, jquery_1.default)('<div>').addClass('state d-none').text(JSON.stringify(self.state));
            self.ui.root.append(self.ui.state);
        }
        else {
        }
        //state_set(old_state);
        let entries = null;
        if (self.ui.entries === null) {
            entries = (0, jquery_1.default)('<div>').addClass('entries');
            self.ui.root.append(entries);
            self.ui.entries = entries;
        }
        else {
            entries = self.ui.entries;
            entries.empty();
        }
        let keywords = (((_a = self.state) === null || _a === void 0 ? void 0 : _a.search) || '').split(/\s+/).map((o) => {
            let action = null;
            let word = null;
            if (o.length > 0) {
                if (o[0] == '+') {
                    action = 'include';
                    word = o.slice(1);
                }
                else if (o[0] == '-') {
                    action = 'exclude';
                    word = o.slice(1);
                }
                else {
                    action = 'include';
                    word = o;
                }
            }
            return {
                action,
                word,
            };
        }).filter((o) => o.action !== null);
        let filtered_entries = sorted_entries.filter((o) => {
            let match = true;
            let text = JSON.stringify(o);
            for (let k of keywords) {
                if (k.action == 'include') {
                    if (text.search(k.word) == -1) {
                        match = false;
                    }
                }
                else if (k.action == 'exclude') {
                    if (text.search(k.word) != -1) {
                        match = false;
                    }
                }
                if (!match) {
                    break;
                }
            }
            return match;
        });
        self.ui.search.find('.total').text(filtered_entries.length);
        for (let o of filtered_entries.reverse()) {
            let raw = JSON.stringify(o[1]);
            let ts = (new Date(o[1].ts));
            let entry = (0, jquery_1.default)('<div>').addClass('entry');
            entry.append((0, jquery_1.default)('<div>').addClass('ts').text(ts.toISOString()));
            entry.append((0, jquery_1.default)('<div>').addClass('header').text(o[1].entry.header));
            entry.append((0, jquery_1.default)('<div>').addClass('teaser').text(o[1].entry.teaser));
            // entry.append($('<pre>').text(raw));
            entries.append(entry);
        }
        GM_addElement('script', {
            "class": 'bridge',
            "textContent": `
        online_fxreader_linkedin.blah('bridge');
      `
        });
    }
}
const l = new Linkedin();
(() => __awaiter(void 0, void 0, void 0, function* () {
    l.clean_page();
    yield l.data_load();
    const disconnect = l.listener_add();
    l.display_init();
}))();
